summaryrefslogtreecommitdiffstats
path: root/qmake/generators/win32/msvc_dsp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qmake/generators/win32/msvc_dsp.cpp')
-rw-r--r--qmake/generators/win32/msvc_dsp.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/qmake/generators/win32/msvc_dsp.cpp b/qmake/generators/win32/msvc_dsp.cpp
index 8534d6908..e027bd121 100644
--- a/qmake/generators/win32/msvc_dsp.cpp
+++ b/qmake/generators/win32/msvc_dsp.cpp
@@ -16,7 +16,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing retquirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -53,7 +53,7 @@ DspMakefileGenerator::writeMakefile(TQTextStream &t)
{
if(!project->variables()["QMAKE_FAILED_RETQUIREMENTS"].isEmpty()) {
/* for now just dump, I need to generated an empty dsp or something.. */
- fprintf(stderr, "Project file not generated because all retquirements not met:\n\t%s\n",
+ fprintf(stderr, "Project file not generated because all requirements not met:\n\t%s\n",
var("QMAKE_FAILED_RETQUIREMENTS").latin1());
return TRUE;
}
@@ -16,7 +16,7 @@
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please